@@ -8,7 +8,7 @@ from weaviate_etl.utilities import get_maxbatch
 from weaviate_etl.utilities import get_verbose
 
 
-def _reset_classification_configuration(instance, client, classification):
+def reset_classification_configuration(instance, client, classification):
     """ resets the classification configuration at the start of a new classification """
 
     ccuuid = None
@@ -82,7 +82,6 @@ def execute_classification(instance, client, classification):
     #pylint: disable=too-many-branches
 
     clause = create_default_where_clause()
-    ccuuid = _reset_classification_configuration(instance, client, classification)
 
     if 'classification_type' in classification:
         ctype = classification['classification_type']
@@ -133,7 +132,7 @@ def import_and_classify(instance, model, classification, datapoints):
     client = get_weaviate_client(instance)
     maxbatch = get_maxbatch(instance)
     verbose = get_verbose(instance)
-    ccuuid = _reset_classification_configuration(instance, client, classification)
+    ccuuid = reset_classification_configuration(instance, client, classification)
 
     iterations = total = count = 0
     importlist = []
@@ -157,7 +156,7 @@ def import_and_classify(instance, model, classification, datapoints):
         import_datapoints(client, model, importlist, maxbatch, verbose)
 
         print("Starting classifying batch", iterations, "with size :", count)
-        execute_classification(client, classification)
+        execute_classification(instance, client, classification)
 
     # update the number of batches in the classification configuration in Weaviate
     if ccuuid is not None:
